import { motion } from 'framer-motion';
import { PaperAirplaneIcon } from '@heroicons/react/24/outline';
import { StaffDto } from "@nice/common";
import { Button } from 'antd';

export interface SendCardProps {
  staff: StaffDto;
}

export function SendCard({ staff }: SendCardProps) {
  return (
    <motion.div
      initial={{ opacity: 0, y: 20 }}
      animate={{ opacity: 1, y: 0 }}
      whileHover={{ scale: 1.005 }}
      transition={{ duration: 0.2 }}
      className={`
        bg-white rounded-xl shadow-sm overflow-hidden border border-gray-100
      `}
    >
      <div className="flex flex-col sm:flex-row">
        {/* Image Container */}
        <div className="sm:w-48 h-64 sm:h-auto flex-shrink-0 bg-gray-100 flex items-center justify-center">
          {staff.meta?.photoUrl ? (
            <img
              src={staff.meta.photoUrl}
              alt={staff.showname}
              className="w-full h-full object-cover"
            />
          ) : (
            <div className="flex flex-col items-center justify-center text-gray-400">
              <svg
                xmlns="http://www.w3.org/2000/svg"
                className="h-16 w-16 mb-2"
                fill="none"
                viewBox="0 0 24 24"
                stroke="currentColor"
              >
                <path
                  strokeLinecap="round"
                  strokeLinejoin="round"
                  strokeWidth={1}
                  d="M16 7a4 4 0 11-8 0 4 4 0 018 0zM12 14a7 7 0 00-7 7h14a7 7 0 00-7-7z"
                />
              </svg>
              <span className="text-sm">暂未上传照片</span>
            </div>
          )}
        </div>

        {/* Content Container */}
        <div className="flex-1 p-6">
          <div className="flex flex-col h-full">
            <div className="mb-4">
              <div className="flex items-center justify-between mb-3">
                <h3 className="text-xl font-semibold text-gray-900">
                  {staff.showname}
                </h3>
                <span className="px-3 py-1 text-sm font-medium bg-blue-50 text-primary rounded-full">
                  {staff.meta?.rank || '未设置职级'}
                </span>
              </div>
              <p className="text-gray-600 mb-4">{staff.department?.name || '未设置部门'}</p>

              {/* Contact Information */}
              <div className="space-y-2 text-sm text-gray-600">
                <p className="flex items-center">
                  <svg className="w-4 h-4 mr-2" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2"
                      d="M3 8l7.89 5.26a2 2 0 002.22 0L21 8M5 19h14a2 2 0 002-2V7a2 2 0 00-2-2H5a2 2 0 00-2 2v10a2 2 0 002 2z" />
                  </svg>
                  {staff.meta?.email || '未设置邮箱'}
                </p>
                <p className="flex items-center">
                  <svg className="w-4 h-4 mr-2" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2"
                      d="M3 5a2 2 0 012-2h3.28a1 1 0 01.948.684l1.498 4.493a1 1 0 01-.502 1.21l-2.257 1.13a11.042 11.042 0 005.516 5.516l1.13-2.257a1 1 0 011.21-.502l4.493 1.498a1 1 0 01.684.949V19a2 2 0 01-2 2h-1C9.716 21 3 14.284 3 6V5z" />
                  </svg>
                  {staff.phoneNumber || '未设置电话'}
                </p>
                <p className="flex items-center">
                  <svg className="w-4 h-4 mr-2" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2"
                      d="M19 21V5a2 2 0 00-2-2H7a2 2 0 00-2 2v16m14 0h2m-2 0h-5m-9 0H3m2 0h5M9 7h1m-1 4h1m4-4h1m-1 4h1m-5 10v-5a1 1 0 011-1h2a1 1 0 011 1v5m-4 0h4" />
                  </svg>
                  {staff.meta?.office || '未设置办公室'}
                </p>
              </div>
            </div>

            <Button
              type="primary"
              size='large'
            >
              <PaperAirplaneIcon className="w-5 h-5" />
              发送信件
            </Button>
          </div>
        </div>
      </div>
    </motion.div>
  );
}
