import { motion } from "framer-motion";
import { Space, Tag } from "antd";
import { PostState } from "@nice/common";
import {
	ClockIcon,
	CheckCircleIcon,
	ExclamationCircleIcon,
} from "@heroicons/react/24/outline";
import { Badge } from "@web/src/app/main/letter/list/LetterCard";
import { useContext } from "react";
import { PostDetailContext } from "../context/PostDetailContext";
import { PostBadge } from "../badge/PostBadge";

interface TitleSectionProps {
	title: string;
	state: PostState;
}

const stateLabels = {
	[PostState.PENDING]: "待处理",
	[PostState.PROCESSING]: "处理中",
	[PostState.RESOLVED]: "已完成",
};

export function TitleSection() {
	const { post, user } = useContext(PostDetailContext);
	return (
		<motion.div
			initial={{ opacity: 0 }}
			animate={{ opacity: 1 }}
			transition={{ delay: 0.2 }}
			className="relative mb-6 flex items-center gap-4">
			{/* Decorative Line */}
			{/* <div className="absolute -left-2 top-1/2 -translate-y-1/2 w-1 h-8 bg-primary" /> */}

			{/* Title */}
			<h1 className="text-xl font-bold text-primary tracking-wider uppercase">
				{post?.title}
			</h1>

			<Space size="small" wrap className="flex-1">
				<PostBadge type="category" value={post?.term?.name} />
				<PostBadge type="state" value={post?.state} />
			</Space>
			{/* </motion.div> */}
		</motion.div>
	);
}
