import { PostState ,PostStateLabels} from "@nice/common";

export function PostBadge({
	type,
	value,
	className = "",
}: {
	type: "priority" | "category" | "state" | "tag";
	value: string;
	className?: string;
}) {

    
	return (
		value && (
			<span
				className={`
                inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium
                ${getBadgeStyle(type, value)}
                transition-all duration-200 ease-in-out transform hover:scale-105
                ${className}
            `}>
				{type === "state" ? PostStateLabels?.[value] : value?.toUpperCase()}
			</span>
		)
	);
}

const BADGE_STYLES = {
	priority: {
		high: "bg-red-100 text-red-800",
		medium: "bg-yellow-100 text-yellow-800",
		low: "bg-green-100 text-green-800",
	},
	category: {
		complaint: "bg-orange-100 text-orange-800",
		suggestion: "bg-blue-100 text-blue-800",
		request: "bg-purple-100 text-purple-800",
		feedback: "bg-teal-100 text-teal-800",
	},
	state: {
		[PostState.PENDING]: "bg-yellow-100 text-yellow-800",
		[PostState.PROCESSING]: "bg-blue-100 text-blue-800",
		[PostState.RESOLVED]: "bg-green-100 text-green-800",
	},
	tag: {
		_: "bg-primary-100 text-primary-800",
	},
} as const;

const getBadgeStyle = (
	type: keyof typeof BADGE_STYLES,
	value: string
): string => {
	if (type === "tag") {
		return "bg-primary-100 text-primary";
	}
	return (
		BADGE_STYLES[type][value as keyof (typeof BADGE_STYLES)[typeof type]] ||
		"bg-gray-100 text-gray-800"
	);
};
