import { Form, Input, Button, Checkbox, Select } from "antd";
import { useState } from "react";
import { useLetterEditor } from "../context/LetterEditorContext";
import { api } from "@nice/client";
import {
	UserOutlined,
	FolderOutlined,
	TagOutlined,
	FileTextOutlined,
} from "@ant-design/icons";

import QuillEditor from "@web/src/components/common/editor/quill/QuillEditor";
import { PostBadge } from "../../detail/badge/PostBadge";

export function LetterBasicForm() {
	const { onSubmit, receiverId, termId, form } = useLetterEditor();
	const { data: receiver } = api.staff.findFirst.useQuery(
		{
			where: {
				id: receiverId,
			},
		},
		{
			enabled: !!receiverId,
		}
	);
	const { data: term } = api.term.findFirst.useQuery(
		{
			where: { id: termId },
		},
		{ enabled: !!termId }
	);

	const handleFinish = async (values: any) => {
		await onSubmit(values);
	};

	return (
		<div className="w-full space-y-6 p-8">
			<Form
				form={form}
				onFinish={handleFinish}
				initialValues={{ meta: { tags: [] }, isPublic: true }}>
				{/* 收件人和板块信息行 */}
				<div className="flex justify-start items-center gap-8 ">
					<div className="flex items-center  font-semibold text-primary">
						<UserOutlined className="w-5 h-5 mr-2 text-primary" />
						<div>收件人：{receiver?.showname}</div>
					</div>
					<PostBadge type="category" value={term?.name}></PostBadge>
				</div>

				{/* 主题输入框 */}
				<div className="space-y-2 mt-4">
					<Form.Item
						required={false} //不显示星号
						label={
							<div className="mb-1 items-center">
								<TagOutlined className="mr-2 text-primary" />
								标题
								<span className="text-secondary-400">
									（必选）
								</span>
							</div>
						}
						name="title"
						rules={[{ required: true, message: "请输入标题" }]}
						labelCol={{ span: 24 }}
						wrapperCol={{ span: 24 }}>
						<Input maxLength={20} placeholder="请输入标题" />
					</Form.Item>
				</div>

				{/* 标签输入 */}
				<div className="space-y-2">
					<Form.Item
						label={
							<span className="block mb-1">
								<TagOutlined className=" mr-2 text-primary" />
								标签
							</span>
						}
						name={["meta", "tags"]}
						labelCol={{ span: 24 }}
						wrapperCol={{ span: 24 }}>
						<Select
							mode="tags"
							placeholder="输入标签后按回车添加"
							value={form.getFieldValue(["meta", "tags"]) || []}
							onChange={(value) => {
								form.setFieldValue(["meta", "tags"], value);
							}}
							tokenSeparators={[",", " "]}
							className="w-full"
							dropdownStyle={{ display: "none" }}
							style={{
								backgroundColor: "#f0f4ff",
								borderColor: "#00308F",
								borderRadius: "6px",
							}}
						/>
					</Form.Item>
				</div>

				{/* 内容输入框 */}
				<div className="space-y-2">
					<Form.Item
						label={
							<span className="block mb-1">
								<FileTextOutlined className=" mr-2 text-primary" />
								内容
								<span className="text-secondary-400">
									（必选）
								</span>
							</span>
						}
						name="content"
						rules={[{ required: true, message: "请输入内容" }]}
						required={false} //不显示星号
						labelCol={{ span: 24 }}
						wrapperCol={{ span: 24 }}>
						<div className="relative rounded-lg border border-slate-200 bg-white shadow-sm">
							<QuillEditor
								maxLength={1000}
								placeholder="请输入内容"
								minRows={6}
								maxRows={12}
								onChange={(content) =>
									form.setFieldValue("content", content)
								}
							/>
						</div>
					</Form.Item>
				</div>

			

				<div className="flex flex-col sm:flex-row items-start sm:items-center justify-end gap-4 border-t border-secondary-100 pt-4">
					<Form.Item
						name="isPublic"
						valuePropName="checked"
						className="mb-0"
						initialValue={true}>
						<Checkbox>是否公开</Checkbox>
					</Form.Item>

					<Button
						type="primary"
						onClick={() => form.submit()}
						className="bg-primary hover:bg-primary-600 w-full sm:w-auto"
						style={{
							transform: "scale(1)",
							transition: "all 0.2s",
						}}
						onMouseEnter={(e) => {
							e.currentTarget.style.transform = "scale(1.02)";
						}}
						onMouseLeave={(e) => {
							e.currentTarget.style.transform = "scale(1)";
						}}>
						提交
					</Button>
				</div>
			</Form>
		</div>
	);
}
